##  Showing Fields in Views
For fields of the Double, Integer, and Single Select type, you can configure their visibility in report and diagram views. To do this, on the right-side panel, navigate to the Options tab indicated by a gear icon, turn the Include in views toggle on or off as needed, then save the changes.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275576e97a44101499af80de9d88e471_LowRes.png)
"Include in views" Toggle on the "Options" Tab
**Note**
For custom fields, the Include in views toggle is turned off by default to avoid overwhelming users with too many view attributes. Once you’ve completed the configuration, you can display a custom field in views by enabling the toggle.
The following image shows how a custom field Maintenance Cost appears in report views.
![Custom Field](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749081d7a441014ae28f0ef9c29c74a_LowRes.png)
Custom Field "Maintenance Cost" in Report Views
